==> foundation-2.7.1.tgz: package/Yen/Yen.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { EmotionIconBase } from '@emotion-icons/emotion-icon';
export var Yen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(EmotionIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M76.275 22.811a.268.268 0 00.079-.191c0-.134-.103-.233-.232-.255v-.017H64.121a.905.905 0 00-.78.463h-.016l-13.281 21.49-13.281-21.49h-.014a.904.904 0 00-.78-.463H23.917a.272.272 0 00-.193.463h-.001l16.42 25.354H25.977v.017c-.025-.002-.046-.015-.072-.015-.637 0-1.153.516-1.153 1.153v4.12h.014a1.146 1.146 0 001.139 1.083c.026 0 .047-.012.072-.014v.015h18.352v6.439H25.977v.002l-.012-.002c-.637 0-1.153.516-1.153 1.153v3.969c0 .637.516 1.153 1.153 1.153l.012-.002v.004h18.352v9.199c-.001.021-.012.038-.012.058 0 .637.516 1.153 1.153 1.153h.002l.001.001h9.141v-.001a1.153 1.153 0 001.151-1.153c0-.011-.006-.021-.006-.031v-9.225h18.433v-.004l.01.002c.637 0 1.153-.516 1.153-1.153v-3.969c0-.637-.516-1.153-1.153-1.153l-.01.002v-.002H55.759v-6.439h18.433v-.003l.01.002c.637 0 1.153-.516 1.153-1.153V49.25h-.014a1.146 1.146 0 00-1.139-1.083l-.01.002v-.004H59.864l16.42-25.354h-.009z"
  }));
});
Yen.displayName = 'Yen';
export var YenDimensions = {
  height: 100,
  width: 100
};

==> foundation-10.15.1.tgz: package/Yen/Yen.esm.js <==
import _extends from "@babel/runtime/helpers/extends";
import * as React from 'react';
import { StyledIconBase } from '@styled-icons/styled-icon';
export var Yen = /*#__PURE__*/React.forwardRef(function (props, ref) {
  var attrs = {
    "fill": "currentColor",
    "xmlns": "http://www.w3.org/2000/svg"
  };
  return /*#__PURE__*/React.createElement(StyledIconBase, _extends({
    iconAttrs: attrs,
    iconVerticalAlign: "middle",
    iconViewBox: "0 0 100 100"
  }, props, {
    ref: ref
  }), /*#__PURE__*/React.createElement("path", {
    d: "M76.275 22.811a.268.268 0 00.079-.191c0-.134-.103-.233-.232-.255v-.017H64.121a.905.905 0 00-.78.463h-.016l-13.281 21.49-13.281-21.49h-.014a.904.904 0 00-.78-.463H23.917a.272.272 0 00-.193.463h-.001l16.42 25.354H25.977v.017c-.025-.002-.046-.015-.072-.015-.637 0-1.153.516-1.153 1.153v4.12h.014a1.146 1.146 0 001.139 1.083c.026 0 .047-.012.072-.014v.015h18.352v6.439H25.977v.002l-.012-.002c-.637 0-1.153.516-1.153 1.153v3.969c0 .637.516 1.153 1.153 1.153l.012-.002v.004h18.352v9.199c-.001.021-.012.038-.012.058 0 .637.516 1.153 1.153 1.153h.002l.001.001h9.141v-.001a1.153 1.153 0 001.151-1.153c0-.011-.006-.021-.006-.031v-9.225h18.433v-.004l.01.002c.637 0 1.153-.516 1.153-1.153v-3.969c0-.637-.516-1.153-1.153-1.153l-.01.002v-.002H55.759v-6.439h18.433v-.003l.01.002c.637 0 1.153-.516 1.153-1.153V49.25h-.014a1.146 1.146 0 00-1.139-1.083l-.01.002v-.004H59.864l16.42-25.354h-.009z"
  }));
});
Yen.displayName = 'Yen';
export var YenDimensions = {
  height: 100,
  width: 100
};
